==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/dbquery_test/loadconnectionsverbose_test.go <==
package dbquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

type ConnTestProperties struct {
	ConnID   string
	AgencyID string
}

func Test_LoadConnectionsVerbose(t *testing.T) {
	testCases := []struct {
		Test                     string
		MockGTFS                 map[int]string
		Sources                  []int
		Date                     uint
		TimeRange                [2]int
		ConnIDs                  []string
		ExpectConnTestProperties []ConnTestProperties
	}{
		{
			Test:     "Works if agency_id undefined in agency.txt; unspecified in route",
			MockGTFS: map[int]string{42: "../testhelper/mockgtfs/gtfs_agency_fmt_nilagencyid.yml"},
			Sources:  []int{42},
			Date:     20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*0),
				UTCify(t, 20240304, "America/New_York", 60*60*24),
			},
			ConnIDs: []string{
				"42_trip_foo_up_wk_2", "42_trip_foo_up_wk_3",
			},
			ExpectConnTestProperties: []ConnTestProperties{
				{"42_trip_foo_up_wk_2", ""},
				{"42_trip_foo_up_wk_3", ""},
			},
		},
		{
			Test:     "Works if agency_id defined in agency.txt; unspecified in route",
			MockGTFS: map[int]string{42: "../testhelper/mockgtfs/gtfs_agency_fmt_oneagencyid.yml"},
			Sources:  []int{42},
			Date:     20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*0),
				UTCify(t, 20240304, "America/New_York", 60*60*24),
			},
			ConnIDs: []string{
				"42_trip_foo_up_wk_2", "42_trip_foo_up_wk_3",
			},
			ExpectConnTestProperties: []ConnTestProperties{
				{"42_trip_foo_up_wk_2", "fooagency"},
				{"42_trip_foo_up_wk_3", "fooagency"},
			},
		},
		{
			Test:     "Works multiple agency_id defined in agency.txt; specified in routed",
			MockGTFS: map[int]string{42: "../testhelper/mockgtfs/gtfs_agency_fmt_multiagencyid.yml"},
			Sources:  []int{42},
			Date:     20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*0),
				UTCify(t, 20240304, "America/New_York", 60*60*24),
			},
			ConnIDs: []string{
				"42_trip_foo_up_wk_2", "42_trip_bar_up_wk_3",
			},
			ExpectConnTestProperties: []ConnTestProperties{
				{"42_trip_foo_up_wk_2", "fooagency"},
				{"42_trip_bar_up_wk_3", "baragency"},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if conns, err := dbquery.LoadConnectionsVerbose(
			sqlxDB, testCase.Sources,
			testCase.Date, testCase.TimeRange[0], testCase.TimeRange[1],
			testCase.ConnIDs,
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(
			testCase.ExpectConnTestProperties,
			mapConnsVerboseToTestProperties(conns),
		) {
			t.Fatalf(
				"LoadConnectionsVerbose Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test,
				testCase.ExpectConnTestProperties,
				mapConnsVerboseToTestProperties(conns),
				dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}

func mapConnsVerboseToTestProperties(conns *[]dbt.ConnectionVerbose) []ConnTestProperties {
	a := []ConnTestProperties{}
	for _, c := range *conns {
		var agencyID string = ""
		if c.AgencyID != nil {
			agencyID = *c.AgencyID
		}
		a = append(a, ConnTestProperties{
			ConnID:   c.ConnID,
			AgencyID: agencyID,
		})
	}
	return a
}

==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/dbquery_test/loadconnectionsverbose_test.go <==
package dbquery_test

import (
	"os"
	"reflect"
	"testing"

	"git.sr.ht/~mil/mobroute/dbquery"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/testhelper/dbquerytesthelper"
)

type ConnTestProperties struct {
	ConnID   string
	AgencyID string
}

func Test_LoadConnectionsVerbose(t *testing.T) {
	testCases := []struct {
		Test                     string
		MockGTFS                 map[int]string
		TimezoneToUTCOffset      map[string]int
		FeedIDs                  []int
		Date                     uint
		TimeRange                [2]int
		ConnIDs                  []string
		ExpectConnTestProperties []ConnTestProperties
	}{
		{
			Test:                "Works if agency_id undefined in agency.txt; unspecified in route",
			MockGTFS:            map[int]string{42: "../testhelper/mockgtfs/gtfs_agency_fmt_nilagencyid.yml"},
			TimezoneToUTCOffset: map[string]int{"America/New_York": -5 * 60 * 60},
			FeedIDs:             []int{42},
			Date:                20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*0),
				UTCify(t, 20240304, "America/New_York", 60*60*24),
			},
			ConnIDs: []string{
				"42_trip_foo_up_wk_2", "42_trip_foo_up_wk_3",
			},
			ExpectConnTestProperties: []ConnTestProperties{
				{"42_trip_foo_up_wk_2", ""},
				{"42_trip_foo_up_wk_3", ""},
			},
		},
		{
			Test:                "Works if agency_id defined in agency.txt; unspecified in route",
			MockGTFS:            map[int]string{42: "../testhelper/mockgtfs/gtfs_agency_fmt_oneagencyid.yml"},
			TimezoneToUTCOffset: map[string]int{"America/New_York": UTCify(t, 20240304, "America/New_York", 0)},
			FeedIDs:             []int{42},
			Date:                20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*0),
				UTCify(t, 20240304, "America/New_York", 60*60*24),
			},
			ConnIDs: []string{
				"42_trip_foo_up_wk_2", "42_trip_foo_up_wk_3",
			},
			ExpectConnTestProperties: []ConnTestProperties{
				{"42_trip_foo_up_wk_2", "fooagency"},
				{"42_trip_foo_up_wk_3", "fooagency"},
			},
		},
		{
			Test:                "Works multiple agency_id defined in agency.txt; specified in routed",
			MockGTFS:            map[int]string{42: "../testhelper/mockgtfs/gtfs_agency_fmt_multiagencyid.yml"},
			TimezoneToUTCOffset: map[string]int{"America/New_York": UTCify(t, 20240304, "America/New_York", 0)},
			FeedIDs:             []int{42},
			Date:                20240304,
			TimeRange: [2]int{
				UTCify(t, 20240304, "America/New_York", 60*60*0),
				UTCify(t, 20240304, "America/New_York", 60*60*24),
			},
			ConnIDs: []string{
				"42_trip_foo_up_wk_2", "42_trip_bar_up_wk_3",
			},
			ExpectConnTestProperties: []ConnTestProperties{
				{"42_trip_foo_up_wk_2", "fooagency"},
				{"42_trip_bar_up_wk_3", "baragency"},
			},
		},
	}

	for _, testCase := range testCases {
		if sqlxDB, dbPath, err := dbquerytesthelper.PrepareMockLoadComputeAndOpenDB(
			testCase.MockGTFS,
		); err != nil {
			t.Fatalf("Error preparing testcase: %v", err)
		} else if conns, err := dbquery.LoadConnectionsVerbose(
			sqlxDB, testCase.FeedIDs, testCase.TimezoneToUTCOffset,
			testCase.Date, testCase.TimeRange[0], testCase.TimeRange[1],
			ptr(testCase.ConnIDs),
			nil,
		); err != nil {
			t.Fatalf("Error: %v: DB: %s", err, dbPath)
		} else if !reflect.DeepEqual(
			testCase.ExpectConnTestProperties,
			mapConnsVerboseToTestProperties(conns),
		) {
			t.Fatalf(
				"LoadConnectionsVerbose Test failed: %s - expected: %v; got: %v; DB: (%s)",
				testCase.Test,
				testCase.ExpectConnTestProperties,
				mapConnsVerboseToTestProperties(conns),
				dbPath,
			)
		} else {
			os.Remove(dbPath)
		}
	}
}

func mapConnsVerboseToTestProperties(conns *[]dbt.ConnectionVerbose) []ConnTestProperties {
	a := []ConnTestProperties{}
	for _, c := range *conns {
		var agencyID string = ""
		if c.AgencyID != nil {
			agencyID = *c.AgencyID
		}
		a = append(a, ConnTestProperties{
			ConnID:   c.ConnID,
			AgencyID: agencyID,
		})
	}
	return a
}
